# Changelog

All notable changes to this project will be documented in this file.

## Unreleased

// Add new changes below this line.

## v0.1.7 (2022-12-18)

- Updated README and added Purview Automation video for PyPI.

## v0.1.6 (2022-12-15)

- Added friendly error message on delete assets.
- Fixed extract collections print sequence.

## v0.1.5 (2022-12-14)

- Fixed safe delete printing sequence (cleaner printing).

## v0.1.4 (2022-12-11)

- Added a friendly error message to the list collections method.
- Added additional automated tests.

## v0.1.3 (2022-12-04)

- Updated README on PyPI to show Python versions.

